import Vue from 'vue';
import { ApolloOperationContext } from '../types';
import { ApolloError, GraphQLError, InputValidationError, NetworkError, ProcessedApolloError, ServerError, UnauthorizedError } from './types';
export declare function isApolloError(error: ApolloError | any): error is ApolloError;
export declare function isGraphQLError(error: GraphQLError | any): error is GraphQLError;
export interface ApolloErrorProcessorOptions<TApp = Vue, TContext = ApolloOperationContext> {
    app?: TApp;
    context?: TContext;
    isUnauthorizedError?: (error: GraphQLError) => boolean;
    onUnauthorizedError?: (error: UnauthorizedError) => boolean | void;
    onInputValidationError?: (error: InputValidationError) => boolean | void;
    onServerError?: (error: ServerError) => boolean | void;
    onNetworkError?: (error: NetworkError) => boolean | void;
    translations?: Record<string, string>;
}
export declare const defaultErrorMessageTranslations: Record<string, string>;
export interface ApolloErrorProcessorResult {
    unhandledErrors: ProcessedApolloError[];
    handledErrors: ProcessedApolloError[];
}
export declare function processApolloError(error: ApolloError, options?: ApolloErrorProcessorOptions): ApolloErrorProcessorResult;
