import { ApolloError, MutationOptions, OperationVariables } from 'apollo-client';
import { DocumentNode } from 'graphql';
import { ClientOptions, DollarApollo } from 'vue-apollo/types/vue-apollo';
import { FetchResult } from 'apollo-link';
import { FetchPolicy, MutationBaseOptions } from 'apollo-client/core/watchQueryOptions';
import { Vue } from 'vue/types/vue';
import { ApolloOperationContext } from './types';
import { ApolloOperationErrorHandlerFunction, ProcessedApolloError, ValidationRuleViolation } from './error';
export declare type ApolloComponentMutationFunction<R = any, TVariables = OperationVariables> = (options: MutationBaseOptions<R, TVariables> & ClientOptions & {
    mutation?: DocumentNode;
    context?: any;
    fetchPolicy?: FetchPolicy;
}) => Promise<FetchResult<R>>;
export declare type ApolloClientMutationFunction<R = any, TVariables = OperationVariables> = (options: MutationOptions<R, TVariables> & ClientOptions) => Promise<FetchResult<R>>;
export declare type VueAppWithApollo = Vue & {
    $apollo: DollarApollo<any>;
};
export declare type ApolloMutationClient<TResult, TVariables extends OperationVariables> = ApolloComponentMutationFunction<TResult, TVariables> | {
    mutate: ApolloClientMutationFunction<TResult, TVariables>;
    [key: string]: any;
};
export declare type MutationOperationFunction<TResult, TVariables extends OperationVariables, TError = ApolloError> = (app: VueAppWithApollo, params: Omit<MutationOperationParams<TResult, TVariables, TError>, 'mutation'>, client?: ApolloMutationClient<TResult, TVariables>) => Promise<MutationResult<TResult>>;
export interface MutationOperationParams<TResult, TVariables extends OperationVariables, TError = ApolloError, TContext = ApolloOperationContext> extends MutationOptions<TResult, TVariables> {
    context?: TContext;
    onError?: ApolloOperationErrorHandlerFunction<TError>;
}
export interface MutationResult<TData> {
    success: boolean;
    data?: TData | null;
    errors?: ProcessedApolloError[];
    validationRuleViolations?: ValidationRuleViolation[];
}
export declare function cleanInput<T extends Record<string, any>>(input: T): T;
export declare function mutateWithErrorHandling<TResult, TVariables extends OperationVariables, TError, TApp extends VueAppWithApollo = VueAppWithApollo>(app: TApp, params: MutationOperationParams<TResult, TVariables, TError>, client?: ApolloMutationClient<TResult, TVariables>): Promise<MutationResult<TResult>>;
export declare function createMutationFunction<TResult, TVariables extends OperationVariables, TError = ApolloError, TApp extends VueAppWithApollo = VueAppWithApollo>(mutation: DocumentNode, onError?: ApolloOperationErrorHandlerFunction<TError, TApp>): MutationOperationFunction<TResult, TVariables, TError>;
